@@ -36,6 +36,6 @@ from . import meshTri
 from . import meshTetra
 from . import reader
 
-__version__ = '0.1.1'
+__all__ = ['mesh2d', 'meshTri', 'meshTetra', 'reader']
+__version__ = '0.1.2'
 
-__all__ = filter(lambda s: not s.startswith('_'), dir())
